@@ -1,8 +1,11 @@
 
 import imp
-import os.path
+import os
+import re
 
 from amazonproduct import HOSTS
+from amazonproduct.processors import objectify, etree, minidom
+from amazonproduct.utils import load_config
 
 _here = os.path.abspath(os.path.dirname(__file__))
 
@@ -19,13 +22,30 @@ XML_TEST_DIR = _here
 
 #: Versions of Amazon API to be tested against 
 TESTABLE_API_VERSIONS = [
-'2010-12-01', '2010-11-01', '2010-10-01', '2010-09-01', '2010-06-01', 
-'2009-11-01', '2009-10-01'
+    d for d in os.listdir(_here) 
+    if re.match(r'^\d{4}-\d{2}-\d{2}$', d)
 ]
 
 #: Locales to test against. 
 TESTABLE_LOCALES = HOSTS.keys()
 
+#ELEMENTTREE_IMPLEMENTATIONS = [
+#    'lxml.etree',
+#    'xml.etree.cElementTree',
+#    'xml.etree.ElementTree',
+#    'cElementTree',
+#    'elementtree.ElementTree',
+#    'elementtree.ElementTree'
+#]
+
+#: Result processors to test with.
+TESTABLE_PROCESSORS = {
+    'objectify': 'amazonproduct.processors.objectify',
+    'etree': 'amazonproduct.processors.etree',
+    'elementtree': 'amazonproduct.processors.elementtree',
+#    'minidom': 'amazonproduct.processors.minidom',
+}
+
 def get_config_value(key, default=None):
     """
     Loads value from config.py or from environment variable or return default
@@ -36,7 +56,6 @@ def get_config_value(key, default=None):
     except AttributeError:
         return os.environ.get(key, default)
 
-AWS_KEY = get_config_value('AWS_KEY', '')
-SECRET_KEY = get_config_value('SECRET_KEY', '')
-OVERWRITE_TESTS = get_config_value('OVERWRITE_TESTS', '')
-
+_config = load_config()
+AWS_KEY = _config.get('access_key', '')
+SECRET_KEY = _config.get('secret_key', '')
